==> canon-runtime-java-0.0.15-sources.jar: org/symphonyoss/s2/canon/runtime/AsyncPathHandler.java <==
/*
 *
 *
 * Copyright 2018 Symphony Communication Services, LLC.
 *
 * Licensed to The Symphony Software Foundation (SSF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.symphonyoss.s2.canon.runtime;

import java.util.concurrent.ExecutorService;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public abstract class AsyncPathHandler<M extends IModel>
extends PathHandler<M>
{
  private static final Logger log_ = LoggerFactory.getLogger(AsyncPathHandler.class);
  
  private final ExecutorService processExecutor_;
  private final ExecutorService responseExecutor_;
  

  public AsyncPathHandler(
      ExecutorService processExecutor,
      ExecutorService responseExecutor,
      int variableCnt, String[] parts)
  {
    super(variableCnt, parts);
    
    if(processExecutor == null)
      throw new IllegalArgumentException("processExecutor is required");
    
    processExecutor_ = processExecutor;
    responseExecutor_ = responseExecutor;
  }

  public ExecutorService getProcessExecutor()
  {
    return processExecutor_;
  }

  public ExecutorService getResponseExecutor()
  {
    return responseExecutor_;
  }
  
//  protected abstract P parsePayload(String request) throws BadFormatException;
//  
//  protected <P,R> void handleWithPayloadResponse(RequestContext context, List<String> pathParams,
//      IPayloadResponseRequestManager<P,R> handler) throws IOException, JapiException
//  {
//    ServletInputStream  in    = context.getRequest().getInputStream();
//    ServletOutputStream out   = context.getResponse().getOutputStream();
//    AsyncContext        async = context.getRequest().startAsync();
//    
//    PayloadResponseRequestManager manager = new PayloadResponseRequestManager(in, out, async, handler);
//    
//    out.setWriteListener(manager);
//    in.setReadListener(manager);
//    
//    System.err.println("isReady=" + in.isReady());
//  }
//  
//  protected void handleWithRequest(RequestContext context, List<String> pathParams) throws IOException, JapiException
//  {
//    throw new NullPointerException("NOT IMPLEMENTED YET");
//  }
//
//  protected void handleWithResponse(RequestContext context, List<String> pathParams) throws IOException, JapiException
//  {
//    throw new NullPointerException("NOT IMPLEMENTED YET");
//  }

  
}

==> canon-runtime-java-0.0.21-sources.jar: org/symphonyoss/s2/canon/runtime/AsyncPathHandler.java <==
/*
 *
 *
 * Copyright 2018 Symphony Communication Services, LLC.
 *
 * Licensed to The Symphony Software Foundation (SSF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.symphonyoss.s2.canon.runtime;

import java.util.concurrent.ExecutorService;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public abstract class AsyncPathHandler
extends PathHandler
{
  private static final Logger log_ = LoggerFactory.getLogger(AsyncPathHandler.class);
  
  private final ExecutorService processExecutor_;
  private final ExecutorService responseExecutor_;
  

  public AsyncPathHandler(
      ExecutorService processExecutor,
      ExecutorService responseExecutor,
      int variableCnt, String[] parts)
  {
    super(variableCnt, parts);
    
    if(processExecutor == null)
      throw new IllegalArgumentException("processExecutor is required");
    
    processExecutor_ = processExecutor;
    responseExecutor_ = responseExecutor;
  }

  public ExecutorService getProcessExecutor()
  {
    return processExecutor_;
  }

  public ExecutorService getResponseExecutor()
  {
    return responseExecutor_;
  }
  
//  protected abstract P parsePayload(String request) throws BadFormatException;
//  
//  protected <P,R> void handleWithPayloadResponse(RequestContext context, List<String> pathParams,
//      IPayloadResponseRequestManager<P,R> handler) throws IOException, JapiException
//  {
//    ServletInputStream  in    = context.getRequest().getInputStream();
//    ServletOutputStream out   = context.getResponse().getOutputStream();
//    AsyncContext        async = context.getRequest().startAsync();
//    
//    PayloadResponseRequestManager manager = new PayloadResponseRequestManager(in, out, async, handler);
//    
//    out.setWriteListener(manager);
//    in.setReadListener(manager);
//    
//    System.err.println("isReady=" + in.isReady());
//  }
//  
//  protected void handleWithRequest(RequestContext context, List<String> pathParams) throws IOException, JapiException
//  {
//    throw new NullPointerException("NOT IMPLEMENTED YET");
//  }
//
//  protected void handleWithResponse(RequestContext context, List<String> pathParams) throws IOException, JapiException
//  {
//    throw new NullPointerException("NOT IMPLEMENTED YET");
//  }

  
}
